@@ -23,11 +23,9 @@ Refer http://goo.gl/GR2o6U for more details.
 import logging
 import os
 
-import six.moves.urllib.parse as urlparse
-import six.moves.urllib.request as urllib
-import suds.sax.element as element
+import urllib.parse as urlparse
+import urllib.request as urllib
 
-from oslo_vmware._i18n import _LW
 from oslo_vmware import service
 from oslo_vmware import vim_util
 
@@ -41,7 +39,8 @@ class Pbm(service.Service):
     """Service class that provides access to the Storage Policy API."""
 
     def __init__(self, protocol='https', host='localhost', port=443,
-                 wsdl_url=None, cacert=None, insecure=True, pool_maxsize=10):
+                 wsdl_url=None, cacert=None, insecure=True, pool_maxsize=10,
+                 connection_timeout=None, op_id_prefix='oslo.vmware'):
         """Constructs a PBM service client object.
 
         :param protocol: http or https
@@ -54,19 +53,22 @@ class Pbm(service.Service):
                          used only if cacert is not specified
         :param pool_maxsize: Maximum number of connections in http
                              connection pool
+        :param op_id_prefix: String prefix for the operation ID.
+        :param connection_timeout: Maximum time in seconds to wait for peer to
+                                   respond.
         """
         base_url = service.Service.build_base_url(protocol, host, port)
         soap_url = base_url + '/pbm'
-        super(Pbm, self).__init__(wsdl_url, soap_url, cacert, insecure,
-                                  pool_maxsize)
+        super().__init__(wsdl_url, soap_url, cacert, insecure,
+                         pool_maxsize, connection_timeout,
+                         op_id_prefix)
 
     def set_soap_cookie(self, cookie):
         """Set the specified vCenter session cookie in the SOAP header
 
         :param cookie: cookie to set
         """
-        elem = element.Element('vcSessionCookie').setText(cookie)
-        self.client.set_options(soapheaders=elem)
+        self._vc_session_cookie = cookie
 
     def retrieve_service_content(self):
         ref = vim_util.get_moref(service.SERVICE_INSTANCE, SERVICE_TYPE)
@@ -159,7 +161,7 @@ def convert_datastores_to_hubs(pbm_client_factory, datastores):
     hubs = []
     for ds in datastores:
         hub = pbm_client_factory.create('ns0:PbmPlacementHub')
-        hub.hubId = ds.value
+        hub.hubId = vim_util.get_moref_value(ds)
         hub.hubType = 'Datastore'
         hubs.append(hub)
     return hubs
@@ -175,7 +177,7 @@ def filter_datastores_by_hubs(hubs, datastores):
     filtered_dss = []
     hub_ids = [hub.hubId for hub in hubs]
     for ds in datastores:
-        if ds.value in hub_ids:
+        if vim_util.get_moref_value(ds) in hub_ids:
             filtered_dss.append(ds)
     return filtered_dss
 
@@ -191,12 +193,12 @@ def get_pbm_wsdl_location(vc_version):
     ver = vc_version.split('.')
     major_minor = ver[0]
     if len(ver) >= 2:
-        major_minor = '%s.%s' % (major_minor, ver[1])
+        major_minor = '{}.{}'.format(major_minor, ver[1])
     curr_dir = os.path.abspath(os.path.dirname(__file__))
     pbm_service_wsdl = os.path.join(curr_dir, 'wsdl', major_minor,
                                     'pbmService.wsdl')
     if not os.path.exists(pbm_service_wsdl):
-        LOG.warning(_LW("PBM WSDL file %s not found."), pbm_service_wsdl)
+        LOG.warning("PBM WSDL file %s not found.", pbm_service_wsdl)
         return
     pbm_wsdl = urlparse.urljoin('file:', urllib.pathname2url(pbm_service_wsdl))
     LOG.debug("Using PBM WSDL location: %s.", pbm_wsdl)
@@ -214,7 +216,7 @@ def get_profiles(session, vm):
     profile_manager = pbm.service_content.profileManager
 
     object_ref = pbm.client.factory.create('ns0:PbmServerObjectRef')
-    object_ref.key = vm.value
+    object_ref.key = vim_util.get_moref_value(vm)
     object_ref.objectType = 'virtualMachine'
 
     return session.invoke_api(pbm, 'PbmQueryAssociatedProfile',
